page_403 = """<html><head><title>403 Forbidden</title></head>
              <div style='background: #ffc;padding: 10px 20px;'>
                <h1>Forbidden (403)</h1>
                <p>CSRF verification failed. Request aborted.</p>
              </div>
              </html>
           """

page_302 = """<html><head><title>302 Error</title></head>
              <div style='background: #ffc;padding: 10px 20px;'>
                <h1>Unvalidate Redirect/Forward (302)</h1>
                <p>Permission Denied. Request aborted.</p>
              </div>
              </html>
           """
